hotspot/src/share/vm/opto/compile.cpp
changeset 33158 f4e6c593ba73
parent 33065 55892792936f
child 33160 c59f1676d27e
--- a/hotspot/src/share/vm/opto/compile.cpp	Wed Oct 07 06:56:58 2015 -0400
+++ b/hotspot/src/share/vm/opto/compile.cpp	Thu Oct 08 12:10:19 2015 +0200
@@ -317,7 +317,7 @@
 // Use breadth-first pass that records state in a Unique_Node_List,
 // recursive traversal is slower.
 void Compile::identify_useful_nodes(Unique_Node_List &useful) {
-  int estimated_worklist_size = unique();
+  int estimated_worklist_size = live_nodes();
   useful.map( estimated_worklist_size, NULL );  // preallocate space
 
   // Initialize worklist
@@ -3314,7 +3314,7 @@
   Final_Reshape_Counts frc;
 
   // Visit everybody reachable!
   // Allocate stack of size C->unique()/2 to avoid frequent realloc
   Node_Stack nstack(live_nodes() >> 1);
   final_graph_reshaping_walk(nstack, root(), frc);
@@ -3314,7 +3314,7 @@
 
   // Visit everybody reachable!
-  // Allocate stack of size C->unique()/2 to avoid frequent realloc
+  // Allocate stack of size C->live_nodes()/2 to avoid frequent realloc
   Node_Stack nstack(live_nodes() >> 1);
   final_graph_reshaping_walk(nstack, root(), frc);